@@ -58,6 +58,7 @@ import qualified Command.Import
 import qualified Command.Map
 import qualified Command.Upgrade
 import qualified Command.Version
+import qualified Command.Watch
 
 cmds :: [Command]
 cmds = concat
@@ -99,6 +100,7 @@ cmds = concat
 	, Command.Map.def
 	, Command.Upgrade.def
 	, Command.Version.def
+	, Command.Watch.def
 	]
 
 options :: [Option]
